@@ -6,6 +6,9 @@ class Base64EncodeAction(BaseAction):
     itype = 'is.workflow.actions.base64encode'
     keyword = 'base64_encode'
 
+    _additional_identifier_field = 'WFEncodeMode'
+    _default_class = True
+
     default_fields = {
         'WFEncodeMode': 'Encode',
     }
@@ -16,6 +19,8 @@ class Base64DecodeAction(BaseAction):
     itype = 'is.workflow.actions.base64encode'
     keyword = 'base64_decode'
 
+    _additional_identifier_field = 'WFEncodeMode'
+
     default_fields = {
         'WFEncodeMode': 'Decode',
     }
