@@ -1,12 +1,14 @@
 import re
 from copy import deepcopy
-from typing import Any, Dict, List, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 
 class BaseAction:
     itype: Union[str, None] = None  # identificator from shortcut source (being used by iOS app): WFWorkflowActionIdentifier
     keyword: Union[str, None] = None  # this keyword is being used in the toml file
     default_fields: Dict = {}  # noqa dictionary with default parameters fields
+    _additional_identifier_field: Union[str, None] = None
+    _default_class: Optional[bool] = None
 
     def __init__(self, data: Union[Dict, None] = None) -> None:
         self.data = data if data is not None else {}
@@ -82,8 +84,8 @@ class GroupIDField(Field):
 
 
 class ChoiceField(Field):
-    def __init__(self, name, choices, required=True, capitalize=False, help=''):
-        super().__init__(name=name, required=required, capitalize=capitalize, help=help)
+    def __init__(self, name, choices, default=None, required=True, capitalize=False, help=''):
+        super().__init__(name=name, required=required, default=default, capitalize=capitalize, help=help)
         self.choices = choices
 
     def process_value(self, value):
@@ -154,13 +156,15 @@ class VariablesField(Field):
 
     def _check_token_match(self, value):
         variable = value.strip('{}')
-        type = self._system_variables.get(variable)
-        if type:
+        var_type = self._system_variables.get(variable)
+        if var_type:
             return {
                 'WFSerializationType': 'WFTextTokenAttachment',
-                'Value': {'Type': type},
+                'Value': {'Type': var_type},
             }
 
+        return None
+
     def _get_variables_dict(self, value: str) -> Dict:
         attachments_by_range, string = self._get_variables_from_text(value)
         return {
@@ -173,12 +177,12 @@ class VariablesField(Field):
         offset = 0
         for m in self._regexp.finditer(value):
             variable_name = m.group().strip('{}')
-            type = self._system_variables.get(variable_name, 'Variable')
+            var_type = self._system_variables.get(variable_name, 'Variable')
             variable_range = f'{{{m.start() - offset}, {1}}}'
             attachments_by_range[variable_range] = {
-                'Type': type,
+                'Type': var_type,
             }
-            if type == 'Variable':
+            if var_type == 'Variable':
                 attachments_by_range[variable_range]['VariableName'] = variable_name
             offset += len(m.group())
 
