@@ -3,7 +3,7 @@ from shortcuts.actions.base import BaseAction, Field, VariablesField
 
 class DateAction(BaseAction):
     '''Date'''
-    type = 'is.workflow.actions.date'
+    itype = 'is.workflow.actions.date'
     keyword = 'date'
 
     default_answer = VariablesField('WFAskActionDefaultAnswer', required=False)
@@ -11,7 +11,7 @@ class DateAction(BaseAction):
 
 class FormatDateAction(BaseAction):
     '''Format date'''
-    type = 'is.workflow.actions.format.date'
+    itype = 'is.workflow.actions.format.date'
     keyword = 'format_date'
 
     format = Field('WFDateFormat')
