@@ -45,3 +45,38 @@ class GetURLAction(BaseAction):
 
         if data and data.get('headers'):
             self.default_fields['ShowHeaders'] = True
+
+
+class URLEncodeAction(BaseAction):
+    '''URL Encode'''
+    itype = 'is.workflow.actions.urlencode'
+    keyword = 'urlencode'
+
+    _additional_identifier_field = 'WFEncodeMode'
+    _default_class = True
+
+    default_fields = {
+        'WFEncodeMode': 'Encode',
+    }
+
+
+class URLDecodeAction(BaseAction):
+    '''URL Dencode'''
+    itype = 'is.workflow.actions.urlencode'
+    keyword = 'urldecode'
+
+    _additional_identifier_field = 'WFEncodeMode'
+
+    default_fields = {
+        'WFEncodeMode': 'Decode',
+    }
+
+
+class ExpandURLAction(BaseAction):
+    '''
+    Expand URL: This action expands and cleans up URLs
+    that have been shortened by a URL shortening
+    service like TinyURL or bit.ly
+    '''
+    itype = 'is.workflow.actions.url.expand'
+    keyword = 'expand_url'
