@@ -2,39 +2,45 @@ import argparse
 import os.path
 
 import shortcuts
-from shortcuts.utils import convert_plist_to_binary, convert_plist_to_xml
+from shortcuts.utils import download_shortcut, is_shortcut_url
 
 
 def convert_shortcut(input_filepath, out_filepath):
     input_format = _get_format(input_filepath)
     out_format = _get_format(out_filepath)
 
-    if input_format == 'plist':
-        convert_plist_to_xml(input_filepath)
+    if input_format == 'url':
+        sc_data = download_shortcut(input_filepath)
+        if out_format == shortcuts.FMT_SHORTCUT:
+            with open(out_filepath, 'wb') as f:
+                f.write(sc_data)
+            return
+        sc = shortcuts.Shortcut.loads(sc_data, file_format=shortcuts.FMT_SHORTCUT)
+    else:
+        with open(input_filepath, 'rb') as f:
+            sc = shortcuts.Shortcut.load(f, file_format=input_format)
 
-    with open(input_filepath, 'rb') as f:
-        sc = shortcuts.Shortcut.load(f, file_format=input_format)
-    with open(out_filepath, 'w') as f:
+    with open(out_filepath, 'wb') as f:
         sc.dump(f, file_format=out_format)
 
-    if out_format == 'plist':
-        convert_plist_to_binary(out_filepath)
-
 
 def _get_format(filepath):
+    if is_shortcut_url(filepath):
+        return 'url'
+
     _, ext = os.path.splitext(filepath)
     ext = ext.strip('.')
-    if ext in ('shortcut', 'plist'):
-        return 'plist'
+    if ext in (shortcuts.FMT_SHORTCUT, 'plist'):
+        return shortcuts.FMT_SHORTCUT
     elif ext == 'toml':
-        return 'toml'
+        return shortcuts.FMT_TOML
 
     raise RuntimeError(f'Unsupported file format: {filepath}: "{ext}"')
 
 
 def main():
     parser = argparse.ArgumentParser(description='Shortcuts: Siri shortcuts creator')
-    parser.add_argument('file', nargs='?', help='Input file: *.(toml|shortcut)')
+    parser.add_argument('file', nargs='?', help='Input file: *.(toml|shortcut|itunes url)')
     parser.add_argument('output', nargs='?', help='Output file: *.(toml|shortcut)')
     parser.add_argument('--version', action='store_true', help='Version information')
 
