@@ -1,11 +1,12 @@
 import collections
 import copy
 import plistlib
-from typing import TYPE_CHECKING, Any, Dict, List, TextIO, Tuple, Type, Union
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Type, Union
 
 import toml
 
-from shortcuts.actions import ITYPE_TO_ACTION_MAP, KEYWORD_TO_ACTION_MAP
+from shortcuts import exceptions
+from shortcuts.actions import actions_registry
 
 
 if TYPE_CHECKING:
@@ -15,11 +16,9 @@ if TYPE_CHECKING:
 
 class BaseLoader:
     @classmethod
-    def load(cls, file_obj: TextIO) -> 'Shortcut':
+    def load(cls, file_obj: BinaryIO) -> 'Shortcut':
         content = file_obj.read()
-        if isinstance(content, (bytes, bytearray)):
-            content = content.decode('utf-8')
-        return cls.loads(content)
+        return cls.loads(content)  # type: ignore
 
     @classmethod
     def loads(cls, string: str) -> 'Shortcut':
@@ -31,18 +30,22 @@ class TomlLoader(BaseLoader):
     def loads(cls, string: str) -> 'Shortcut':
         from shortcuts import Shortcut  # noqa
 
+        if isinstance(string, (bytearray, bytes)):
+            string = string.decode('utf-8')
+
         shortcut_dict = toml.loads(string)
         shortcut = Shortcut(name=shortcut_dict.get('name', 'python-shortcuts'))
 
         if not isinstance(shortcut_dict.get('action'), list):
             raise ValueError('toml file must contain "action" array with actions')
 
-        for action in shortcut_dict['action']:
-            action_params = copy.deepcopy(action)
+        for params in shortcut_dict['action']:
+            action_params = copy.deepcopy(params)
             del action_params['type']
-            shortcut.actions.append(
-                KEYWORD_TO_ACTION_MAP[action['type']](data=action_params)
-            )
+
+            action_class = actions_registry.get_by_keyword(params['type'])
+            action = action_class(data=action_params)
+            shortcut.actions.append(action)
 
         return shortcut
 
@@ -69,23 +72,11 @@ class PListLoader(BaseLoader):
 
     @classmethod
     def _action_from_dict(cls, action_dict: Dict) -> 'BaseAction':
-        action_class = cls._get_action_class(action_dict)
-
-        if not action_class:
-            msg = f'''
-            Unknown shortcut action: {type}
-
-            Please, check documentation to add new shortcut action, or create an issue:
-            Docs: https://github.com/alexander-akhmetov/python-shortcuts/tree/master/docs/new_action.md
-
-            https://github.com/alexander-akhmetov/python-shortcuts/
-
-            Action dictionary:
-
-            {action_dict}
-            '''
-            raise RuntimeError(msg)
-
+        identifier = action_dict['WFWorkflowActionIdentifier']
+        action_class = actions_registry.get_by_itype(
+            itype=identifier,
+            action_params=action_dict,
+        )
         shortcut_name_to_field_name = {
             f.name: f._attr for f in action_class().fields
         }
@@ -97,81 +88,6 @@ class PListLoader(BaseLoader):
 
         return action_class(data=params)
 
-    @classmethod
-    def _get_action_class(cls, action_dict: Dict) -> Union[Type['BaseAction'], None]:
-        identifier = action_dict['WFWorkflowActionIdentifier']
-        action_class = ITYPE_TO_ACTION_MAP.get(identifier)
-
-        # in some cases we have action classes with the same itype (identifier)
-        # but they have different parameters
-        #
-        # For example, Base64EncodeAction and Base64DecodeAction
-        # classes have the same itype: "is.workflow.actions.base64encode"
-        # we need to check parameters to determine which action class we need to use
-        #
-        # todo: action-based common solution
-        if identifier == 'is.workflow.actions.conditional':
-            action_class = cls._get_if_else_action_class(action_dict)
-        elif identifier == 'is.workflow.actions.base64encode':
-            action_class = cls._get_base64_action_class(action_dict)
-        elif identifier == 'is.workflow.actions.repeat.count':
-            action_class = cls._get_repeat_action_class(action_dict)
-        elif identifier == 'is.workflow.actions.choosefrommenu':
-            action_class = cls._get_menu_action_class(action_dict)
-
-        return action_class
-
-    @classmethod
-    def _get_if_else_action_class(cls, action_dict: Dict) -> Type['BaseAction']:
-        """Returns If-Else-EndIf action class based on WFControlFlowMode parameter of action_dict"""
-        from shortcuts.actions import IfAction, ElseAction, EndIfAction
-        return cls._get_action_class_by_wf_control_flow(
-            from_classes=(IfAction, ElseAction, EndIfAction),
-            action_dict=action_dict,
-        )
-
-    @classmethod
-    def _get_repeat_action_class(cls, action_dict: Dict) -> Type['BaseAction']:
-        """Returns Repeat-Start or Repeat-End action class based on WFControlFlowMode parameter of action_dict"""
-        from shortcuts.actions import RepeatEndAction, RepeatStartAction
-        return cls._get_action_class_by_wf_control_flow(
-            from_classes=(RepeatEndAction, RepeatStartAction),
-            action_dict=action_dict,
-        )
-
-    @classmethod
-    def _get_menu_action_class(cls, action_dict: Dict) -> Type['BaseAction']:
-        """Returns Menu action class based on WFControlFlowMode parameter of action_dict"""
-        from shortcuts.actions import MenuStartAction, MenuItemAction, MenuEndAction
-        return cls._get_action_class_by_wf_control_flow(
-            from_classes=(MenuStartAction, MenuItemAction, MenuEndAction),
-            action_dict=action_dict,
-        )
-
-    @classmethod
-    def _get_action_class_by_wf_control_flow(cls,
-                                             from_classes: Tuple[Type['BaseAction'], ...],
-                                             action_dict: Dict) -> Type['BaseAction']:
-        """Returns class from `from_classes` based on WFControlFlowMode parameter of action_dict"""
-        flow_to_action = {a.default_fields['WFControlFlowMode']: a for a in from_classes}  # type: ignore
-        wf_control_flow_mode = action_dict['WFWorkflowActionParameters']['WFControlFlowMode']
-        return flow_to_action[wf_control_flow_mode]
-
-    @classmethod
-    def _get_base64_action_class(cls, action_dict: Dict) -> Type['BaseAction']:
-        """Returns Base64EncodeAction or Base64DecodeAction based on WFEncodeMode parameter of action_dict"""
-        from shortcuts.actions import Base64EncodeAction, Base64DecodeAction
-        action_params = action_dict['WFWorkflowActionParameters']
-
-        # by default it's encode, even if it doesn't have WFEncodeMode parameter
-        encode_mode = action_params.get('WFEncodeMode', 'Encode')
-        if encode_mode == 'Encode':
-            return Base64EncodeAction
-        elif encode_mode == 'Decode':
-            return Base64DecodeAction
-
-        raise RuntimeError(f'Unknown WFEncodeMode: "{encode_mode}"')
-
 
 class WFDeserializer:
     """
@@ -198,7 +114,9 @@ class WFDeserializer:
         if deserializer:
             return deserializer(self._data).deserialized_data
 
-        raise RuntimeError(f'Unknown serialization type: {self._data.get("WFSerializationType")}')
+        raise exceptions.UnknownSerializationType(
+            f'Unknown serialization type: {self._data.get("WFSerializationType")}',
+        )
 
 
 class WFTokenAttachmentParameterStateField(WFDeserializer):
@@ -212,6 +130,7 @@ class WFTextTokenAttachmentField(WFDeserializer):
         if self._data['Value'].get('Type') == 'Ask':
             return '{{ask_when_run}}'
 
+        # if self._data['Value']['Type'] == 'Variable':
         return self._data['Value']['VariableName']
 
 
@@ -266,8 +185,8 @@ class WFVariableStringField(WFDeserializer):
         for variable_range, variable_data in value['attachmentsByRange'].items():
             if variable_data['Type'] not in supported_types:
                 # it doesn't support magic variables yet
-                raise RuntimeError(
-                    f'Unsupported variable type: {variable_data["Type"]} (possibly it is a magic variable)',
+                raise exceptions.UnknownVariableError(
+                    f'Unknown variable type: {variable_data["Type"]} (possibly it is a magic variable)',
                 )
 
             if variable_data['Type'] == 'Variable':
